"use client"
import CheckItem from "./CheckItem"
import { CheckItemType } from "@/types/CheckItem"
import { useRef } from "react"
import { QueryClient, QueryClientProvider } from "@tanstack/react-query"

export default function Checker() {
  const IPv4 = useRef("")
  const IPv6 = useRef("")

  const checkList: CheckItemType[] = [
    {
      id: "IPv6",
      name: "公网 IPv6 地址",
      fetcher: () => fetch("https://test.ipv6test.online/ip/myip").then((res) => res.json()),
      content: (data) => {
        const success = data?.version == 6
        if (success && data.address != null) {
          IPv6.current = data.address
        }
        return {
          state: success ? "ok" : "error",
          text: success ? `${data?.address}` : "未检测到",
        }
      },
    },
    {
      id: "IPv4",
      name: "公网 IPv4 地址",
      fetcher: () => fetch("https://test.ipv6test.online/ip/myip").then((res) => res.json()),
      content: (data) => {
        const success = data?.version == 4

        if (success && data.address != null) {
          IPv4.current = data.address
        }

        return {
          state: success ? "ok" : "error",
          text: success ? `${data?.address}` : "未检测到",
        }
      },
    },
    {
      id: "ipv4andipv6",
      name: "双协议栈测试",
      fetcher: () => fetch("https://test.ipv6test.online/ip/myip").then((res) => res.json()),
      content: (data) => {
        const isIPv6 = data?.version == 6
        const isIPv4 = data?.version == 4

        return {
          state: isIPv6 ? "ok" : "error",
          text: isIPv6 ? "IPv6访问优先" : isIPv4 ? "IPv4访问优先" : "未检测到",
        }
      },
    },
    {
      id: "ISP",
      name: "ISP",
      fetcher: () =>
        fetch("https://test.ipv6test.online/ip/isp", {
          method: "POST",
          body: JSON.stringify({
            address: IPv6.current,
          }),
        }).then((res) => res.json()),
      content: (data) => {
        return {
          text: data.isp,
        }
      },
    },
  ]

  const queryClient = new QueryClient();


  return (
    <QueryClientProvider client={queryClient}>
      {checkList.map((item, i) => {
        return (
          <CheckItem
            key={i}
            id={item.id}
            name={item.name}
            fetcher={item.fetcher}
            content={item.content}
          />
        )
      })}
    </QueryClientProvider>
  )
}
